@@ -25,23 +25,24 @@ class CacheManager:
     def __init__(self, path):
         pass
 
-    @property
-    def path(self):
-        return None
-
     def find_all(self):
+        """Find all stored cache."""
         return None
 
     def read(self, name):
+        """Reads cache with ``name`` if it exists."""
         return None
 
-    def dump(self, name):
+    def dump(self, name, data):
+        """Save data into cache."""
         return None
 
     def cleanup(self, name):
+        """Cleanup all cache with a ``name``"""
         return None
 
     def debug_size(self):
+        """Get size of cache for debugging."""
         return sys.getsizeof(self)
 
 
@@ -55,16 +56,11 @@ class BufferedCacheManager(CacheManager):
 
         super().__init__(path)
 
-    @property
-    def path(self):
-        """Returns ``None``. Only here to work with the same interface as ``FileCacheManager``."""
-        return None
-
     def find_all(self):
         """
         Find all cache stored in memory.
 
-        :rtype: :class:`str`
+        :rtype: :class:`generator`
         """
         return (
             i
@@ -87,11 +83,13 @@ class BufferedCacheManager(CacheManager):
 
         els = name.split('*') # splits across *
 
+        need_remove = []
+
         for i in self._buf:
             for n, j in enumerate(els):
                 i = i.rstrip('.dat')
                 if not (
-                    j == '' or ( j in i and \
+                    j == '' or (j in i and
                         (i.index(j) >= i.index(els[0 if n < 1 else n - 1]))
                         )
                     ):
@@ -106,9 +104,17 @@ class BufferedCacheManager(CacheManager):
                     # If it is, we make sure its after the previous
                     # component (second check).
             else:
-                del self._buf[i]
+                need_remove.append(i)
+
+        for i in need_remove:
+            del self._buf[i]
 
     def debug_size(self):
+        """
+        Get size of internal cache for debugging.
+
+        :returns: Cache size in memory in bytes.
+        """
         return sys.getsizeof(self._buf)
 
 class FileCacheManager(CacheManager):
@@ -123,7 +129,7 @@ class FileCacheManager(CacheManager):
 
         super().__init__(path)
 
-        Path(path).mkdir(parents=True, exist_ok=True) # Creates cache folder
+        Path(path).mkdir(parents=True, exist_ok=True)  # Creates cache folder
 
         ## Cache is identified with its `name` attribute. Cache can be read by keeping track of this
         ## value and reading it with `read` later on.
@@ -141,7 +147,7 @@ class FileCacheManager(CacheManager):
         """
         Return a list of all tracked cache files.
 
-        :rtype: :class:`str`
+        :rtype: :class:`generator`
         """
         return (
             i.rstrip('.dat')
@@ -179,10 +185,10 @@ class FileCacheManager(CacheManager):
         try:
             for i in os.listdir(self._path):
                 for n, j in enumerate(els):
-                    i = i.rstrip('.dat')
+                    k = i.rstrip('.dat')
                     if not (
-                        j == '' or ( j in i and \
-                            (i.index(j) >= i.index(els[0 if n < 1 else n - 1]))
+                        j == '' or (j in i and
+                            (k.index(j) >= k.index(els[0 if n < 1 else n - 1]))
                             )
                         ):
                         break
