@@ -88,7 +88,8 @@ class Client:
 
         try:
             # Does the acutal request
-            return self.session.get(f"{self.BASE}/{endpoint}{parameters}", timeout=(4, 4)).json()
+            return self.session.get(f"{self.BASE}/{endpoint}{parameters}",
+                                    timeout=(4, 4)).json()
         except Exception as e:
             raise errors.InternalError(f"Unable to fetch data at this time: {e}", 9999)
 
@@ -102,7 +103,7 @@ class Client:
         if loc == '':
             raise errors.QueryNotProvided('Location cannot be empty.', 0)
 
-        return [ # Generates a list of city names containing the string `loc`
+        return [  # Generates a list of city names containing the string `loc`
             i for i in self.cities if loc.lower() in i['name'].lower()
         ]
 
@@ -131,25 +132,27 @@ class Client:
 
         # https://docs.python.org/3/library/datetime.html#strftime-strptime-behavior
 
+        # If cache exists (not None), it will be read and an `HourlyPoint` object will be returned
+
         n = self.cache.read(mode)
         if n:
-            # If cache exists (not None), it will be read and an `HourlyPoint` object will be returned
             return n
 
         response = self.__make_request('current.json', f'?key={self._token}&q={loc}')
 
         e = Client.__is_error_code(response)
         if e:
-            raise e # We're not going to handle the error here, so anyone using the function can do it themselves
+            raise e
 
-        data = types.HourlyPoint.from_raw(response["location"], response["current"]) # Creates the `HourlyPoint` object
+        # Creates the `HourlyPoint` object
+        data = types.HourlyPoint.from_raw(response["location"], response["current"])
 
         self.cache.cleanup(mode.split('-now-')[0] + '-now-*') # Discard any old cache
         self.cache.dump(mode, data) # Writes cache
 
         return data
 
-        ## The same pattern is followed for all other API methods implemented.
+        # The same pattern is followed for all other API methods implemented.
 
     def forecast(self, loc, days=3):
         """
